@@ -2,8 +2,8 @@
 
 /*
  * $Author: tom $
- * $Date: 2011/05/15 19:27:11 $
- * $Revision: 1.65 $
+ * $Date: 2021/12/16 00:40:47 $
+ * $Revision: 1.69 $
  */
 
 DeclareCDKObjects (BUTTONBOX, Buttonbox, setCdk, Int);
@@ -16,10 +16,10 @@ CDKBUTTONBOX *newCDKButtonbox (CDKSCREEN *cdkscreen,
 			       int yPos,
 			       int height,
 			       int width,
-			       char *title,
+			       const char *title,
 			       int rows,
 			       int cols,
-			       char **buttons,
+			       CDK_CSTRING2 buttons,
 			       int buttonCount,
 			       chtype highlight,
 			       boolean Box,
@@ -168,7 +168,6 @@ CDKBUTTONBOX *newCDKButtonbox (CDKSCREEN *cdkscreen,
  */
 int activateCDKButtonbox (CDKBUTTONBOX *buttonbox, chtype *actions)
 {
-   chtype input = 0;
    boolean functionKey;
    int ret;
 
@@ -179,7 +178,7 @@ int activateCDKButtonbox (CDKBUTTONBOX *buttonbox, chtype *actions)
    {
       for (;;)
       {
-	 input = (chtype)getchCDKObject (ObjOf (buttonbox), &functionKey);
+	 chtype input = (chtype)getchCDKObject (ObjOf (buttonbox), &functionKey);
 
 	 /* Inject the character into the widget. */
 	 ret = injectCDKButtonbox (buttonbox, input);
@@ -217,7 +216,6 @@ static int _injectCDKButtonbox (CDKOBJS *object, chtype input)
 {
    /* *INDENT-EQLS* */
    CDKBUTTONBOX *widget = (CDKBUTTONBOX *)object;
-   int firstButton      = 0;
    int lastButton       = widget->buttonCount - 1;
    int ppReturn         = 1;
    int ret              = unknownInt;
@@ -246,6 +244,8 @@ static int _injectCDKButtonbox (CDKOBJS *object, chtype input)
       }
       else
       {
+	 int firstButton = 0;
+
 	 switch (input)
 	 {
 	 case KEY_LEFT:
@@ -421,7 +421,7 @@ static void _drawCDKButtonbox (CDKOBJS *object, boolean Box)
 void drawCDKButtonboxButtons (CDKBUTTONBOX *buttonbox)
 {
    /* *INDENT-EQLS* */
-   int row              = TitleLinesOf (buttonbox) + 1;
+   int row;
    int col              = (int)(buttonbox->colAdjust / 2);
    int currentButton    = 0;
    int x, y;
