@@ -1,4 +1,4 @@
-/* $Id: cdkselection.c,v 1.12 2012/03/22 09:36:03 tom Exp $ */
+/* $Id: cdkselection.c,v 1.17 2024/03/12 17:48:06 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -25,7 +25,6 @@ int main (int argc, char **argv)
    CDKSCREEN *cdkScreen         = 0;
    CDKSELECTION *widget         = 0;
    CDKBUTTONBOX *buttonWidget   = 0;
-   WINDOW *cursesWindow         = 0;
    chtype *holder               = 0;
    char *item                   = 0;
    char *CDK_WIDGET_COLOR       = 0;
@@ -77,6 +76,7 @@ int main (int argc, char **argv)
    title        = CDKparamString (&params, 'T');
    numbers      = CDKparamValue (&params, 'n', FALSE);
    spos         = CDKparsePosition (CDKparamString (&params, 's'));
+   (void)numbers;
 
    /* If the user asked for an output file, try to open it. */
    if (outputFile != 0)
@@ -113,7 +113,7 @@ int main (int argc, char **argv)
 	 {
 	    /* Split the line on CTRL-V. */
 	    items = CDKsplitString (scrollList[x], CTRL ('V'));
-	    fields = (int)CDKcountStrings ((CDK_CSTRING2) items);
+	    fields = (int)CDKcountStrings ((CDK_CSTRING2)items);
 
 	    /* Check the field count. */
 	    if (fields == 1)
@@ -152,12 +152,13 @@ int main (int argc, char **argv)
    {
       /* Split the scroll lines up. */
       scrollList = CDKsplitString (list, '\n');
-      scrollLines = (int)CDKcountStrings ((CDK_CSTRING2) scrollList);
+      scrollLines = (int)CDKcountStrings ((CDK_CSTRING2)scrollList);
    }
 
-   /* Did they supply a chopice list. */
+   /* Did they supply a choice list. */
    if (choices == 0)
    {
+      choiceList = calloc(3, sizeof (char *));
       choiceList[0] = copyChar ("Yes ");
       choiceList[1] = copyChar ("No ");
       choiceSize = 2;
@@ -166,14 +167,10 @@ int main (int argc, char **argv)
    {
       /* Split the choices up. */
       choiceList = CDKsplitString (choices, '\n');
-      choiceSize = (int)CDKcountStrings ((CDK_CSTRING2) choiceList);
+      choiceSize = (int)CDKcountStrings ((CDK_CSTRING2)choiceList);
    }
 
-   /* Start curses. */
-   cursesWindow = initscr ();
-
-   /* Create the CDK screen. */
-   cdkScreen = initCDKScreen (cursesWindow);
+   cdkScreen = initCDKScreen (NULL);
 
    /* Start color. */
    initCDKColor ();
@@ -196,8 +193,8 @@ int main (int argc, char **argv)
    /* Create the scrolling list. */
    widget = newCDKSelection (cdkScreen, xpos, ypos, spos,
 			     height, width, title,
-			     (CDK_CSTRING2) scrollList, scrollLines,
-			     (CDK_CSTRING2) choiceList, choiceSize,
+			     (CDK_CSTRING2)scrollList, scrollLines,
+			     (CDK_CSTRING2)choiceList, choiceSize,
 			     A_REVERSE,
 			     boxWidget, shadowWidget);
    CDKfreeStrings (choiceList);
@@ -225,7 +222,7 @@ int main (int argc, char **argv)
    {
       /* Split the button list up. */
       buttonList = CDKsplitString (buttons, '\n');
-      buttonCount = (int)CDKcountStrings ((CDK_CSTRING2) buttonList);
+      buttonCount = (int)CDKcountStrings ((CDK_CSTRING2)buttonList);
 
       /* We need to create a buttonbox widget. */
       buttonWidget = newCDKButtonbox (cdkScreen,
@@ -234,7 +231,7 @@ int main (int argc, char **argv)
 				       + widget->boxHeight - 1),
 				      1, widget->boxWidth - 1,
 				      0, 1, buttonCount,
-				      (CDK_CSTRING2) buttonList, buttonCount,
+				      (CDK_CSTRING2)buttonList, buttonCount,
 				      A_REVERSE, boxWidget, FALSE);
       CDKfreeStrings (buttonList);
 
@@ -335,12 +332,11 @@ int main (int argc, char **argv)
    ExitProgram (selection);
 }
 
-static int widgetCB (EObjectType cdktype GCC_UNUSED,
-		     void *object GCC_UNUSED,
+static int widgetCB (EObjectType cdktype GCC_UNUSED, void *object GCC_UNUSED,
 		     void *clientData,
 		     chtype key)
 {
    CDKBUTTONBOX *buttonbox = (CDKBUTTONBOX *)clientData;
-   (void) injectCDKButtonbox (buttonbox, key);
+   (void)injectCDKButtonbox (buttonbox, key);
    return (TRUE);
 }
