@@ -1,4 +1,4 @@
-/* $Id: cdkviewer.c,v 1.12 2012/03/22 00:22:03 tom Exp $ */
+/* $Id: cdkviewer.c,v 1.16 2024/03/12 17:48:15 tom Exp $ */
 
 #include <cdk_test.h>
 
@@ -26,7 +26,6 @@ int main (int argc, char **argv)
    /* *INDENT-EQLS* */
    CDKSCREEN *cdkScreen         = 0;
    CDKVIEWER *widget            = 0;
-   WINDOW *cursesWindow         = 0;
    char *filename               = 0;
    char *CDK_WIDGET_COLOR       = 0;
    char *temp                   = 0;
@@ -87,6 +86,7 @@ int main (int argc, char **argv)
    if (buttons == 0)
    {
       /* *INDENT-EQLS* */
+      buttonList        = calloc(3, sizeof(char *));
       buttonList[0]     = copyChar ("OK");
       buttonList[1]     = copyChar ("Cancel");
       buttonCount       = 2;
@@ -95,7 +95,7 @@ int main (int argc, char **argv)
    {
       /* Split the button list up. */
       buttonList        = CDKsplitString (buttons, '\n');
-      buttonCount       = (int)CDKcountStrings ((CDK_CSTRING2) buttonList);
+      buttonCount       = (int)CDKcountStrings ((CDK_CSTRING2)buttonList);
    }
 
    /* Set up the title of the viewer. */
@@ -105,9 +105,7 @@ int main (int argc, char **argv)
       title = copyChar (tempTitle);
    }
 
-   /* Set up CDK. */
-   cursesWindow = initscr ();
-   cdkScreen = initCDKScreen (cursesWindow);
+   cdkScreen = initCDKScreen (NULL);
 
    /* Start color. */
    initCDKColor ();
@@ -129,7 +127,7 @@ int main (int argc, char **argv)
 
    /* Create the viewer widget. */
    widget = newCDKViewer (cdkScreen, xpos, ypos, height, width,
-			  (CDK_CSTRING2) buttonList, buttonCount, A_REVERSE,
+			  (CDK_CSTRING2)buttonList, buttonCount, A_REVERSE,
 			  boxWidget, shadowWidget);
 
    /* Check to make sure we created the file viewer. */
@@ -156,7 +154,7 @@ int main (int argc, char **argv)
    bindCDKObject (vVIEWER, widget, 'S', widgetCB, 0);
 
    /* Set the information needed for the viewer. */
-   setCDKViewer (widget, title, (CDK_CSTRING2) messageList, messageLines,
+   setCDKViewer (widget, title, (CDK_CSTRING2)messageList, messageLines,
 		 A_REVERSE, interpret, showInfoLine, TRUE);
 
    /* Activate the viewer. */
@@ -205,7 +203,7 @@ static void saveInformation (CDKVIEWER *widget)
       mesg[1] = "<C>Escape hit. Scrolling window information not saved.";
       mesg[2] = " ";
       mesg[3] = "<C>Press any key to continue.";
-      popupLabel (ScreenOf (widget), (CDK_CSTRING2) mesg, 4);
+      popupLabel (ScreenOf (widget), (CDK_CSTRING2)mesg, 4);
 
       destroyCDKEntry (entry);
       return;
@@ -224,7 +222,7 @@ static void saveInformation (CDKVIEWER *widget)
       mesg[2] = temp;
       mesg[3] = " ";
       mesg[4] = "<C>Press any key to continue.";
-      popupLabel (ScreenOf (widget), (CDK_CSTRING2) mesg, 5);
+      popupLabel (ScreenOf (widget), (CDK_CSTRING2)mesg, 5);
    }
    else
    {
@@ -237,7 +235,7 @@ static void saveInformation (CDKVIEWER *widget)
       mesg[2] = temp;
       mesg[3] = " ";
       mesg[4] = "<C>Press any key to continue.";
-      popupLabel (ScreenOf (widget), (CDK_CSTRING2) mesg, 5);
+      popupLabel (ScreenOf (widget), (CDK_CSTRING2)mesg, 5);
       freeChar (msg_1);
    }
 
@@ -277,8 +275,7 @@ static int dumpViewer (CDKVIEWER *widget, char *filename)
    return listSize;
 }
 
-static int widgetCB (EObjectType cdktype GCC_UNUSED,
-		     void *object,
+static int widgetCB (EObjectType cdktype GCC_UNUSED, void *object,
 		     void *clientData GCC_UNUSED,
 		     chtype key GCC_UNUSED)
 {
